Introduce GrBatch subclasses GrDrawBatch and GrVertexBatch to prepare for non-drawing batches

Review URL: https://codereview.chromium.org/1293583002
diff --git a/src/gpu/GrBatchTest.h b/src/gpu/GrBatchTest.h
index 9daa960..32e8e28 100644
--- a/src/gpu/GrBatchTest.h
+++ b/src/gpu/GrBatchTest.h
@@ -12,7 +12,7 @@
 
 #ifdef GR_TEST_UTILS
 
-class GrBatch;
+class GrDrawBatch;
 class GrContext;
 class SkRandom;
 
@@ -21,19 +21,19 @@
  * are generally useful for GrBatch testing
  */
 
-// Batches should define test functions using BATCH_TEST_DEFINE.  The other macros defined below
-// are used exclusively by the test harness.
-typedef GrBatch* (*BatchTestFunc)(SkRandom* random, GrContext* context);
-#define BATCH_TEST_DEFINE(Batch) \
-    GrBatch* Batch##__Test(SkRandom* random, GrContext* context)
-#define BATCH_TEST_EXTERN(Batch) \
-    extern GrBatch* Batch##__Test(SkRandom*, GrContext* context);
-#define BATCH_TEST_ENTRY(Batch) \
+// Batches should define test functions using DRAW_BATCH_TEST_DEFINE.  The other macros defined
+// below are used exclusively by the test harness.
+typedef GrDrawBatch* (*BatchTestFunc)(SkRandom* random, GrContext* context);
+#define DRAW_BATCH_TEST_DEFINE(Batch) \
+    GrDrawBatch* Batch##__Test(SkRandom* random, GrContext* context)
+#define DRAW_BATCH_TEST_EXTERN(Batch) \
+    extern GrDrawBatch* Batch##__Test(SkRandom*, GrContext* context);
+#define DRAW_BATCH_TEST_ENTRY(Batch) \
     Batch##__Test
-#define BATCH_TEST_FRIEND(Batch) \
-    friend GrBatch* Batch##__Test(SkRandom* random, GrContext* context);
+#define DRAW_BATCH_TEST_FRIEND(Batch) \
+    friend GrDrawBatch* Batch##__Test(SkRandom* random, GrContext* context);
 
-GrBatch* GrRandomBatch(SkRandom*, GrContext*);
+GrDrawBatch* GrRandomDrawBatch(SkRandom*, GrContext*);
 
 #endif
 #endif